@@ -7,7 +7,6 @@ from fastapi.staticfiles import StaticFiles
 from starlette.responses import FileResponse
 from starlette.responses import PlainTextResponse
 
-from ice.routes import agents
 from ice.routes import traces
 from ice.trace import trace_dir
 
@@ -16,7 +15,6 @@ logger = logging.getLogger(__name__)
 dist_dir = Path(__file__).parent / "ui"
 
 app = FastAPI()
-app.include_router(agents.router)
 app.include_router(traces.router)
 app.mount(
     "/api/traces/", StaticFiles(directory=trace_dir), name="static"
